# This file was auto-generated by Fern from our API Definition.

from ...environment import CandidApiEnvironment
from .resources.v_3.client import AsyncV3Client, V3Client


class EncountersClient:
    def __init__(self, *, environment: CandidApiEnvironment = CandidApiEnvironment.PRODUCTION, token: str):
        self._environment = environment
        self._token = token
        self.v_3 = V3Client(environment=self._environment, token=self._token)


class AsyncEncountersClient:
    def __init__(self, *, environment: CandidApiEnvironment = CandidApiEnvironment.PRODUCTION, token: str):
        self._environment = environment
        self._token = token
        self.v_3 = AsyncV3Client(environment=self._environment, token=self._token)
