# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime


class EncounterProviderBase(pydantic.BaseModel):
    first_name: typing.Optional[str] = pydantic.Field(
        description=("If the billing provider is an individual, this should be set instead of organization name\n")
    )
    last_name: typing.Optional[str] = pydantic.Field(
        description=("If the billing provider is an individual, this should be set instead of organization name\n")
    )
    organization_name: typing.Optional[str] = pydantic.Field(
        description=("If the billing provider is an organization, this should be set instead of first + last name\n")
    )

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}
