# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ....core.datetime_utils import serialize_datetime
from ...commons.types.claim_id import ClaimId
from ...era.types.era import Era
from ...service_lines.types.service_line import ServiceLine
from .claim_status import ClaimStatus


class Claim(pydantic.BaseModel):
    claim_id: ClaimId
    status: ClaimStatus
    clearinghouse: typing.Optional[str]
    clearinghouse_claim_id: typing.Optional[str]
    payer_claim_id: typing.Optional[str]
    service_lines: typing.List[ServiceLine]
    eras: typing.List[Era]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        json_encoders = {dt.datetime: serialize_datetime}
